LibraryError

Enum LibraryError 

pub enum LibraryError {
    PlaylistExists,
    LibraryNotInitialized,
    NoSuchPlaylist,
    IndexOutOfBounds,
    DuplicateItems,
    NoSuchTrack,
    StateNotReadable,
    StateWriteFailed,
    StateNotAFile,
}
An error originating from the music library module of the daemon.

Variants



PlaylistExists

Could not complete the operation because a playlist with the provided name already exists.



LibraryNotInitialized

Could not perform the operation because the music library is not initialized.

This can happen if a command is sent to early and the music library is not yet initialized.



NoSuchPlaylist

There is no playlist in the music library with the provided name.



IndexOutOfBounds

The provided item index was out of bounds.



DuplicateItems

The provided list contained duplicate values.



NoSuchTrack

The provided track is not registered in the library.



StateNotReadable

Could not read the contents of the library state file.



StateWriteFailed

Could not write the library state to a file.



StateNotAFile

The library state path is not a file.