pub struct Playlist {
pub name: String,
pub tracks: Vec<Track>,
}Expand description
Struct representing a playlist in the music library.
Fields
name: StringThe name of the playlist.
Playlist names are unique.
tracks: Vec<Track>The content of the playlist.
All tracks must already be in the music library. If a track is removed from the library (eg. by removing an audio file from the music directory and reloading the library), it will also be removed from all the playlists.